==> members-facade-2.0.0-20191022.124328-82-sources.jar: com/bizvane/members/facade/service/card/response/IntegralChangeResponseModel.java <==
package com.bizvane.members.facade.service.card.response;

import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/18.
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class IntegralChangeResponseModel implements Serializable {

    private static final long serialVersionUID = 5564679076600709284L;

    @ApiModelProperty(name = "brandId", value = "品牌Id")
    private Long brandId;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "cardNo", value = "会员卡号")
    private String cardNo;

    @ApiModelProperty(name = "changeDate", value = "变更时间")
    private Date changeDate;

    @ApiModelProperty(name = "changeIntegral", value = "变更积分")
    private Integer changeIntegral;

    @ApiModelProperty(name = "changeType", value = "调整类型")
    private String changeType;

    @ApiModelProperty(name = "businessType",value = "业务类型")
    private String businessType;

    @ApiModelProperty(name = "offlineBrandCode", value = "线下品牌code")
    private String offlineBrandCode;

    @ApiModelProperty(name = "integralAdjustId", value = "线下流水id")
    private String integralAdjustId;

    @ApiModelProperty(name = "code", value = "响应状态码")
    private Integer code;

    @ApiModelProperty(name = "message", value = "响应信息")
    private String message;
}

==> members-facade-2.0.0-20191212.094133-177-sources.jar: com/bizvane/members/facade/service/card/response/IntegralChangeResponseModel.java <==
package com.bizvane.members.facade.service.card.response;

import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;
import java.util.Date;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/18.
 */
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class IntegralChangeResponseModel implements Serializable {

    private static final long serialVersionUID = 5564679076600709284L;

    @ApiModelProperty(name = "brandId", value = "品牌Id")
    private Long brandId;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "cardNo", value = "会员卡号")
    private String cardNo;

    @ApiModelProperty(name = "changeDate", value = "变更时间")
    private Date changeDate;

    @ApiModelProperty(name = "changeIntegral", value = "变更积分")
    private Integer changeIntegral;

    @ApiModelProperty(name = "changeType", value = "调整类型")
    private String changeType;

    @ApiModelProperty(name = "businessType", value = "业务类型")
    private String businessType;

    @ApiModelProperty(name = "offlineBrandCode", value = "线下品牌code")
    private String offlineBrandCode;

    @ApiModelProperty(name = "integralAdjustId", value = "线下流水id")
    private String integralAdjustId;

    @ApiModelProperty(name = "code", value = "响应状态码")
    private Integer code;

    @ApiModelProperty(name = "message", value = "响应信息")
    private String message;


    @ApiModelProperty(name = "errorStatus", value = "错误状态")
    private Integer errorStatus;

    @ApiModelProperty(name = "errorMessage", value = "错误信息")
    private String errorMessage;

    @ApiModelProperty(name = "errorBody",value = "错误对象信息")
    private String errorBody;

}
